==> qtjambi-network-debuginfo-macos-6.5.3.jar: sources/QtJambiNetwork/QDnsTextRecord_shell.cpp <==
#include <QtCore/QtGlobal>
#include <qtnetwork-config.h>
#if QT_CONFIG(dnslookup)
#include <QtNetwork/qdnslookup.h>
#endif //QT_CONFIG(dnslookup)
#include <QtCore/QVariant>
#include <QtCore/QList>
#include <QtCore/qbytearray.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if QT_CONFIG(dnslookup)


void deleter_QDnsTextRecord(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDnsTextRecord")
    QDnsTextRecord *_ptr = reinterpret_cast<QDnsTextRecord *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}


#endif // QT_CONFIG(dnslookup)

// emitting (writeConstructors)
// new QDnsTextRecord()
void __qt_construct_QDnsTextRecord_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDnsTextRecord()")
#if QT_CONFIG(dnslookup)
    Q_UNUSED(__java_arguments)
    QDnsTextRecord *__qt_this = new(__qtjambi_ptr) QDnsTextRecord();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
}

// new QDnsTextRecord(QDnsTextRecord)
void __qt_construct_QDnsTextRecord_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDnsTextRecord(QDnsTextRecord)")
#if QT_CONFIG(dnslookup)
    jobject other0 = __java_arguments[0].l;
    const QDnsTextRecord& __qt_other0 = qtjambi_cast<const QDnsTextRecord& >(__jni_env, other0);
    QDnsTextRecord *__qt_this = new(__qtjambi_ptr) QDnsTextRecord(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
}

// destruct QDnsTextRecord
void __qt_destruct_QDnsTextRecord(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDnsTextRecord")

#if QT_CONFIG(dnslookup)

    reinterpret_cast<QDnsTextRecord*>(ptr)->~QDnsTextRecord();

#else
    Q_UNUSED(ptr)

#endif // QT_CONFIG(dnslookup)

}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDnsTextRecord::QDnsTextRecord()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsTextRecord_initialize_1native__Lio_qt_network_QDnsTextRecord_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDnsTextRecord::QDnsTextRecord()")
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDnsTextRecord_0, sizeof(QDnsTextRecord), typeid(QDnsTextRecord), false, &deleter_QDnsTextRecord, nullptr);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDnsTextRecord::QDnsTextRecord(QDnsTextRecord)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsTextRecord_initialize_1native__Lio_qt_network_QDnsTextRecord_2Lio_qt_network_QDnsTextRecord_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDnsTextRecord::QDnsTextRecord(QDnsTextRecord)")
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDnsTextRecord_1, sizeof(QDnsTextRecord), typeid(QDnsTextRecord), false, &deleter_QDnsTextRecord, &arguments);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDnsTextRecord::name()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsTextRecord_name_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        const QDnsTextRecord *__qt_this = QtJambiAPI::objectFromNativeId<QDnsTextRecord>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDnsTextRecord::name()const", __qt_this)
        QString __qt_return_value = __qt_this->name();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDnsTextRecord::operator=(QDnsTextRecord)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsTextRecord_assign_1native_1cref_1QDnsTextRecord__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        QDnsTextRecord *__qt_this = QtJambiAPI::objectFromNativeId<QDnsTextRecord>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDnsTextRecord::operator=(QDnsTextRecord)", __qt_this)
        const QDnsTextRecord& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QDnsTextRecord>(other0);
        (*__qt_this) = __qt_other0;
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDnsTextRecord::swap(QDnsTextRecord&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsTextRecord_swap_1native_1ref_1QDnsTextRecord__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        QDnsTextRecord *__qt_this = QtJambiAPI::objectFromNativeId<QDnsTextRecord>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDnsTextRecord::swap(QDnsTextRecord&)", __qt_this)
        QDnsTextRecord& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QDnsTextRecord>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDnsTextRecord::timeToLive()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsTextRecord_timeToLive_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        const QDnsTextRecord *__qt_this = QtJambiAPI::objectFromNativeId<QDnsTextRecord>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDnsTextRecord::timeToLive()const", __qt_this)
        quint32 __qt_return_value = __qt_this->timeToLive();
        __java_return_value = jint(__qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDnsTextRecord::values()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsTextRecord_values_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        const QDnsTextRecord *__qt_this = QtJambiAPI::objectFromNativeId<QDnsTextRecord>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDnsTextRecord::values()const", __qt_this)
        QList<QByteArray> __qt_return_value = __qt_this->values();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsTextRecord_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {

#if QT_CONFIG(dnslookup)

        const QDnsTextRecord *__qt_this = QtJambiAPI::objectFromNativeId<QDnsTextRecord>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);

#else
        Q_UNUSED(__this_nativeId)
#endif // QT_CONFIG(dnslookup)

    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDnsTextRecord(){
    using namespace RegistryAPI;

#if QT_CONFIG(dnslookup)

    const std::type_info& typeId = registerValueTypeInfo<QDnsTextRecord>("QDnsTextRecord", "io/qt/network/QDnsTextRecord");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QDnsTextRecord, {
        ConstructorInfo(&__qt_construct_QDnsTextRecord_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QDnsTextRecord_1, "Lio/qt/network/QDnsTextRecord;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDnsTextRecord);
    registerMetaType<QDnsTextRecord>("QDnsTextRecord");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#endif //QT_CONFIG(dnslookup)

}

==> qtjambi-network-debuginfo-macos-6.5.5.jar: sources/QtJambiNetwork/QDnsTextRecord_shell.cpp <==
#include <QtCore/QtGlobal>
#include <qtnetwork-config.h>
#if QT_CONFIG(dnslookup)
#include <QtNetwork/qdnslookup.h>
#endif //QT_CONFIG(dnslookup)
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if QT_CONFIG(dnslookup)


void deleter_QDnsTextRecord(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDnsTextRecord")
    QDnsTextRecord *_ptr = reinterpret_cast<QDnsTextRecord *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}


#endif // QT_CONFIG(dnslookup)

// emitting (writeConstructors)
// new QDnsTextRecord()
void __qt_construct_QDnsTextRecord(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDnsTextRecord()")
#if QT_CONFIG(dnslookup)
    Q_UNUSED(__java_arguments)
    QDnsTextRecord *__qt_this = new(__qtjambi_ptr) QDnsTextRecord();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    Q_UNUSED(__qtjambi_is_generic)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
}

// QDnsTextRecord::QDnsTextRecord()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsTextRecord_initialize_1native__Lio_qt_network_QDnsTextRecord_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDnsTextRecord::QDnsTextRecord()")
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDnsTextRecord, sizeof(QDnsTextRecord), typeid(QDnsTextRecord), false, &deleter_QDnsTextRecord, nullptr);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QDnsTextRecord(QDnsTextRecord)
void __qt_construct_QDnsTextRecord_cref_QDnsTextRecord(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDnsTextRecord(QDnsTextRecord)")
#if QT_CONFIG(dnslookup)
    jobject other0 = __java_arguments[0].l;
    const QDnsTextRecord& __qt_other0 = qtjambi_cast<const QDnsTextRecord& >(__jni_env, other0);
    QDnsTextRecord *__qt_this = new(__qtjambi_ptr) QDnsTextRecord(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    Q_UNUSED(__qtjambi_is_generic)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
}

// QDnsTextRecord::QDnsTextRecord(QDnsTextRecord)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsTextRecord_initialize_1native__Lio_qt_network_QDnsTextRecord_2Lio_qt_network_QDnsTextRecord_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDnsTextRecord::QDnsTextRecord(QDnsTextRecord)")
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDnsTextRecord_cref_QDnsTextRecord, sizeof(QDnsTextRecord), typeid(QDnsTextRecord), false, &deleter_QDnsTextRecord, &arguments);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QDnsTextRecord
void __qt_destruct_QDnsTextRecord(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDnsTextRecord")

#if QT_CONFIG(dnslookup)

    reinterpret_cast<QDnsTextRecord*>(ptr)->~QDnsTextRecord();

#else
    Q_UNUSED(ptr)

#endif // QT_CONFIG(dnslookup)

}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDnsTextRecord::name()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsTextRecord_name_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        const QDnsTextRecord *__qt_this = QtJambiAPI::objectFromNativeId<QDnsTextRecord>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDnsTextRecord::name()const", __qt_this)
        QString __qt_return_value = __qt_this->name();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDnsTextRecord::operator=(QDnsTextRecord)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsTextRecord_assign_1native_1cref_1QDnsTextRecord__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        QDnsTextRecord *__qt_this = QtJambiAPI::objectFromNativeId<QDnsTextRecord>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDnsTextRecord::operator=(QDnsTextRecord)", __qt_this)
        const QDnsTextRecord& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QDnsTextRecord>(other0);
        (*__qt_this) = __qt_other0;
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDnsTextRecord::swap(QDnsTextRecord&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsTextRecord_swap_1native_1ref_1QDnsTextRecord__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        QDnsTextRecord *__qt_this = QtJambiAPI::objectFromNativeId<QDnsTextRecord>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDnsTextRecord::swap(QDnsTextRecord&)", __qt_this)
        QDnsTextRecord& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QDnsTextRecord>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDnsTextRecord::timeToLive()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsTextRecord_timeToLive_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        const QDnsTextRecord *__qt_this = QtJambiAPI::objectFromNativeId<QDnsTextRecord>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDnsTextRecord::timeToLive()const", __qt_this)
        quint32 __qt_return_value = __qt_this->timeToLive();
        __java_return_value = jint(__qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDnsTextRecord::values()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsTextRecord_values_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        const QDnsTextRecord *__qt_this = QtJambiAPI::objectFromNativeId<QDnsTextRecord>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDnsTextRecord::values()const", __qt_this)
        QList<QByteArray> __qt_return_value = __qt_this->values();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsTextRecord_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {

#if QT_CONFIG(dnslookup)

        const QDnsTextRecord *__qt_this = QtJambiAPI::objectFromNativeId<QDnsTextRecord>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);

#else
        Q_UNUSED(__this_nativeId)
#endif // QT_CONFIG(dnslookup)

    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDnsTextRecord(){
    using namespace RegistryAPI;

#if QT_CONFIG(dnslookup)

    const std::type_info& typeId = registerValueTypeInfo<QDnsTextRecord>("QDnsTextRecord", "io/qt/network/QDnsTextRecord");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QDnsTextRecord, {
        ConstructorInfo(&__qt_construct_QDnsTextRecord, nullptr)
       ,ConstructorInfo(&__qt_construct_QDnsTextRecord_cref_QDnsTextRecord, "Lio/qt/network/QDnsTextRecord;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDnsTextRecord);
    registerMetaType<QDnsTextRecord>("QDnsTextRecord");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#endif //QT_CONFIG(dnslookup)

}
